
#include "MyWindow.h"
#include <iostream>
#include <FL/fl_draw.h>


MyWindow::MyWindow(int width, int height, char* title) : Fl_Window(width, height, title)
{
   image = NULL;
}

MyWindow::~MyWindow()
{
   delete image;
}


void MyWindow::draw()
{
   // setup image
   static bool firstTime = true;
   if (firstTime)
   {
      image = TargaImage::Load_Image("flower.tga");
      if (image == NULL)
         std::cerr << "Failed to load image." << std::endl;
      else
      {
         size(image->width, image->height);
         ModifyImage();
      }

      firstTime = false;
   }

   // draw the image
   if (image != NULL)
      fl_draw_image(image->data, 0, 0, image->width, image->height, 4);
}


void MyWindow::ModifyImage()
{
   if (image == NULL)
      return;

   TargaImage* secondImage = TargaImage::Load_Image("tree.tga");
   if (secondImage == NULL)
   {
      std::cerr << "Failed to load second image." << std::endl;
      return;
   }

   int sourceCenterX          = 200,
       sourceCenterY          = 200,
       destinationCenterX     = 200,
       destinationCenterY     = 150,
       radius                 = 50;

   for (int yOffset = -radius; yOffset <= radius; ++yOffset)
   {
      int sourceY = sourceCenterY + yOffset;
      int destinationY = destinationCenterY + yOffset;

      if (sourceY >= 0 && sourceY < secondImage->height && destinationY >= 0 && destinationY < image->height)
      {
         for (int xOffset = -radius; xOffset <= radius; ++xOffset)
         {
            int sourceX = sourceCenterX + xOffset;
            int destinationX = destinationCenterX + xOffset;

            if (sourceX >= 0 && sourceX < secondImage->width && destinationX >= 0 && destinationX < image->width)
            {
               unsigned char* sourcePixel = secondImage->data + (sourceY * secondImage->width + sourceX) * 4;
               unsigned char* destinationPixel = image->data + (destinationY * image->width + destinationX) * 4;

               for (int i = 0; i < 4; ++i)
                  destinationPixel[i] = sourcePixel[i];
            }
         }
      }
   }

   delete secondImage;
}